
# THIS FILE IS GENERATED FROM syned SETUP.PY
short_version = '1.0.21'
version = '1.0.21'
full_version = '1.0.21.dev0+37a2e7e'
git_revision = '37a2e7e4e28c1219be6404e2aa63aa4cdffe5427'
release = False

if not release:
    version = full_version
    short_version += ".dev"
